#	Generate a vplot file that draws migration curves
#
#	vprmg.x par=vprmg.p out=vprmg.v 
#
# FILES:
#	INPUT:	
#	OUTPUT:
#		stdout:	vplot file
#		
# PARAMETERS:
#	FROM INPUT:
#	FROM PAR:
#		xll,yll,xur,yur the true coordinates of the vplot
#		plotcol=6 	color of plot
#		plotfat=1	fat of plot
#		wantframe=1	=0 no frame; =1 frame
#				
#
# NOTE:
#% end of self doc
#
#-------------
# keyword:
#-------------

integer narray

from par:	integer narray=11

allocate:	real xx(narray),zz(narray)

subroutine submain(narray,xx,zz)

integer nz,nx,nxc,narray,iz,ix,ixc,iarray
integer plotcol,plotfat,titlesz,titlefat,fat
integer yreverse,wantframe
integer outfd, output
real z0,x0,dz,dx,xc0,dxc,zscat,xscat
real xll,yll,xur,yur
real xmin,zmin,xmax,zmax,xrange,zrange,zxrange
real xcenter,zcenter,xscale,zscale
real x,z,xc,x1,z1,x2,z2,zp,xp
real gamma,gammasq,theta,theta1,theta2,rr
real xx(narray),zz(narray)
character*50 out
character*50 title
character*150 longstr

# PARAMETERS
#    INPUT 
	from par:	integer n1:nz=101,n2:nx=101,nxc=(nx-1)/2+1
	from par:	integer plotcol=6,plotfat=1,titlesz=12,titlefat=5
	from par:	integer yreverse=-1,wantframe=1
	from par:	real o1:z0=0,o2:x0=0.,d1:dz=0.01,d2:dx=0.01
	from par:	real xc0=x0-4*(nx-1)*dx,dxc=18.*dx,gamma=1.
	from par:	real zscat=z0+0.5*(nz-1)*dz,xscat=x0+0.5*(nx-1)*dx
	from par:	real xll=3.075,yll=1.37,xur=10.575,yur=8.87
	from par:	character title=" "

#    OUTPUT

# CHECK

# FILES
#   INPUT

#   OUTPUT
	outfd = output()
	if(getch('out','s',out) == 0)
	   call vpfilep(outfd)
	else
	   call vpfile(out)

	call hclose()

# CALCULATION 
	#set parameters
	xmin = x0
	zmin = z0
	xmax = x0+(nx-1)*dx
	zmax = z0+(nz-1)*dz
	xcenter=0.5*(xmin+xmax)
	zcenter=0.5*(zmin+zmax)
	xrange = xmax-xmin
	zrange = zmax-zmin
	zxrange = sqrt(xrange*xrange+zrange*zrange)

	# set vplot scales
	call vpuorig(xmin,zmin)
	if(yreverse == 1)
	   call vporig(xll,yll)
	else
	   call vporig(xll,yur)
        xscale = (xur-xll)/(xmax-xmin)
        zscale = yreverse*(yur-yll)/(zmax-zmin)
	call vpscale(xscale,zscale)

	# set parameters
	gammasq = gamma**2

	# draw curves
	call vpcolor(5)
	fat = 2*plotfat
	call vpfat(fat)
	do ixc = 1,nxc
	{
	   xc = xc0+(ixc-1)*dxc
	   z1 = 1.e12
	   x1 = 1.e12
	   do iarray = 1,100*narray
	   {
	      theta = -2.*atan(1.)+(iarray-1)*4.*atan(1.)/(100*narray-1)
	      x = xc+gamma*sqrt((xscat-xc)**2+zscat**2)*sin(theta)
	      z = gamma*sqrt((xscat-xc)**2+zscat**2)*cos(theta)
	      if(z >= zmin & z <= zmax & x >= xmin & x <= xmax)
	      {
	         if(z1 >= zmin & z1 <= zmax & x1 >= xmin & x1 <= xmax)
	            call vpudraw(x,z)
	         else
	            call vpumove(x,z)
	      }
	      x1 = x
	      z1 = z
	   }
	}

	# draw envelope
	call vpdash(0.2,0.2,0.2,0.2)
	call vpcolor(3)
	fat = 6*plotfat
	call vpfat(fat)
	z1 = 1.e12
	x1 = 1.e12
	do ix = 1,nx
	{
	   x = x0+(ix-1)*dx
	   z = sqrt(gammasq*zscat**2+gammasq*(1.-gammasq)/_
	       ((1.-gammasq)**2+1.e-12)*(x-xscat)**2)
	   if(z >= zmin & z <= zmax & x >= xmin & x <= xmax)
	      if(z1 >= zmin & z1 <= zmax & x1 >= xmin & x1 <= xmax)
	         call vpudraw(x,z)
	      else
	         call vpumove(x,z)
	   x1 = x
	   z1 = z
	}
	call vpdash(0.,0.,0.,0.)

	# draw the position of scatterer
#	do iarray = 1,narray
#	{
#	   theta = (iarray-1)*8*atan(1.)/(narray-1)
#	   xx(iarray) = xscat+0.008*zxrange*sin(theta)
#	   zz(iarray) = zscat+0.008*zxrange*cos(theta)
#	}
#	call vpcolor(7)
#	call vpufill(xx,zz,narray)
#	call vpcolor(7)
#	fat = 4*plotfat
#	call vpfat(fat)
#	call vpupline(xx,zz,narray)

#	fat = 2.*plotfat
#	call vpfat(fat)
#	call vpdash(0.1,0.1,0.1,0.1)

# write title
	call vpcolor(7)
	call vpfat(titlefat)
        call vptjust(2,1)
        x = xcenter
        z = zmin-0.008*titlesz*zxrange
        call vputext(x,z,titlesz,0,title)

	call vpcolor(7)
	call vpfat(2)
	call vptjust(2,3)
	x = 0.5*xmax+0.5*xmin
	z = 0.75*zmax+0.25*zmin
	call vputext(x,z,10,0,'Envelope')
	call vptfont(-1,-1,2)
	x = 0.5*xmax+0.5*xmin
	z = 0.25*zmax+0.75*zmin
	call vputext(x,z,10,0,'Curves')

# draw a frame
	if(wantframe != 0.)
	{
	   call vpcolor(7)
	   call vpfat(1)
	   call vpumove(xmin,zmin)
	   call vpudraw(xmin,zmax)
	   call vpudraw(xmax,zmax)
	   call vpudraw(xmax,zmin)
	   call vpudraw(xmin,zmin)
	}
	   
stop
end
